@@ -23,3 +23,24 @@ PROGRAM_NAME = 'ocrmypdf'
 __version__ = pkg_resources.get_distribution('ocrmypdf').version
 
 VERSION = __version__
+
+from .exceptions import (
+    ExitCode,
+    BadArgsError,
+    PdfMergeFailedError,
+    MissingDependencyError,
+    UnsupportedImageFormatError,
+    DpiError,
+    OutputFileAccessError,
+    PriorOcrFoundError,
+    InputFileError,
+    SubprocessOutputError,
+    EncryptedPdfError,
+    TesseractConfigError,
+)
+
+from . import helpers
+from . import hocrtransform
+from . import leptonica
+from . import pdfa
+from . import pdfinfo
