@@ -24,37 +24,37 @@ from subprocess import run, STDOUT, PIPE, CalledProcessError
 from ..exceptions import MissingDependencyError
 
 
-
-def get_version(program, *,
-        version_arg='--version', regex=r'(\d+(\.\d+)*)'):
+def get_version(program, *, version_arg='--version', regex=r'(\d+(\.\d+)*)'):
     "Get the version of the specified program"
-    args_prog = [
-        program,
-        version_arg
-    ]
+    args_prog = [program, version_arg]
     try:
         proc = run(
-            args_prog, close_fds=True, universal_newlines=True,
-            stdout=PIPE, stderr=STDOUT, check=True)
+            args_prog,
+            close_fds=True,
+            universal_newlines=True,
+            stdout=PIPE,
+            stderr=STDOUT,
+            check=True,
+        )
         output = proc.stdout
     except FileNotFoundError as e:
         raise MissingDependencyError(
-            "Could not find program '{}' on the PATH".format(
-                program)) from e
+            f"Could not find program '{program}' on the PATH"
+        ) from e
     except CalledProcessError as e:
         if e.returncode < 0:
             raise MissingDependencyError(
-                "Ran program '{}' but it exited with an error:\n{}".format(
-                    program, e.output)) from e
+                f"Ran program '{program}' but it exited with an error:\n{e.output}"
+            ) from e
         raise MissingDependencyError(
-            "Could not find program '{}' on the PATH".format(
-                program)) from e
+            f"Could not find program '{program}' on the PATH"
+        ) from e
     try:
         version = re.match(regex, output.strip()).group(1)
     except AttributeError as e:
         raise MissingDependencyError(
-            ("The program '{}' did not report its version. "
-            "Message was:\n{}").format(program, output)
+            f"The program '{program}' did not report its version. "
+            f"Message was:\n{output}"
         )
 
     return version
