@@ -15,26 +15,28 @@
 # You should have received a copy of the GNU General Public License
 # along with OCRmyPDF.  If not, see <http://www.gnu.org/licenses/>.
 
-import sys
 import os
-import re
 import shutil
-from functools import lru_cache
+import sys
 from collections import namedtuple
-from textwrap import dedent
-from subprocess import PIPE, CalledProcessError, \
-    TimeoutExpired, check_output, STDOUT
 from contextlib import suppress
+from functools import lru_cache
+from os import fspath
+from subprocess import (
+    PIPE,
+    STDOUT,
+    CalledProcessError,
+    TimeoutExpired,
+    check_output,
+    run,
+)
+from textwrap import dedent
 
-import PyPDF2 as pypdf
-
+from . import get_version
 from ..exceptions import MissingDependencyError, TesseractConfigError
 from ..helpers import page_number
-from . import get_version
 
-OrientationConfidence = namedtuple(
-    'OrientationConfidence',
-    ('angle', 'confidence'))
+OrientationConfidence = namedtuple('OrientationConfidence', ('angle', 'confidence'))
 
 HOCR_TEMPLATE = """<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
@@ -43,8 +45,8 @@ HOCR_TEMPLATE = """<?xml version="1.0" encoding="UTF-8"?>
  <head>
   <title></title>
 <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
-  <meta name='ocr-system' content='tesseract 3.05.00' />
-  <meta name='ocr-capabilities' content='ocr_page ocr_carea ocr_par ocr_line ocrx_word'/>
+  <meta name='ocr-system' content='tesseract 4.0.0' />
+  <meta name='ocr-capabilities' content='ocr_page ocr_carea ocr_par ocr_line ocrx_word ocrp_wconf'/>
 </head>
 <body>
   <div class='ocr_page' id='page_1' title='image "_blank.png"; bbox 0 0 {0} {1}; ppageno 0'>
@@ -67,57 +69,53 @@ def v4():
 @lru_cache(maxsize=1)
 def has_textonly_pdf():
     """Does Tesseract have textonly_pdf capability?
-    
-    Available in 3.05.01, and v4.00.00alpha since January 2017. Best to 
+
+    Available in v4.00.00alpha since January 2017. Best to
     parse the parameter list
     """
-    args_tess = [
-        'tesseract',
-        '--print-parameters',
-        'pdf'
-    ]
+    args_tess = ['tesseract', '--print-parameters', 'pdf']
     params = ''
     try:
-        params = check_output(
-                args_tess, universal_newlines=True, stderr=STDOUT)
+        params = check_output(args_tess, universal_newlines=True, stderr=STDOUT)
     except CalledProcessError as e:
-        print("Could not --print-parameters from tesseract",
-              file=sys.stderr)
+        print("Could not --print-parameters from tesseract", file=sys.stderr)
         raise MissingDependencyError from e
     if 'textonly_pdf' in params:
         return True
     return False
 
 
-def psm():
-    "If Tesseract 4.0, use argument --psm instead of -psm"
-    return '--psm' if v4() else '-psm'
-
-
 @lru_cache(maxsize=1)
 def languages():
-    args_tess = [
-        'tesseract',
-        '--list-langs'
-    ]
-    try:
-        langs = check_output(
-                args_tess, universal_newlines=True, stderr=STDOUT)
-    except CalledProcessError as e:
-        msg = dedent("""Tesseract failed to report available languages.
+    def lang_error(output):
+        msg = dedent(
+            """Tesseract failed to report available languages.
         Output from Tesseract:
         -----------
-        """)
-        msg += e.output
+        """
+        )
+        msg += output
         print(msg, file=sys.stderr)
+
+    args_tess = ['tesseract', '--list-langs']
+    try:
+        proc = run(
+            args_tess, universal_newlines=True, stdout=PIPE, stderr=STDOUT, check=True
+        )
+        output = proc.stdout
+    except CalledProcessError as e:
+        lang_error(e.output)
         raise MissingDependencyError from e
-    return set(lang.strip() for lang in langs.splitlines()[1:])
+
+    header, *rest = output.splitlines()
+    if not header.startswith('List of available languages'):
+        lang_error(output)
+        raise MissingDependencyError
+    return set(lang.strip() for lang in rest)
 
 
 def tess_base_args(langs, engine_mode):
-    args = [
-        'tesseract',
-    ]
+    args = ['tesseract']
     if langs:
         args.extend(['-l', '+'.join(langs)])
     if engine_mode is not None and v4():
@@ -125,23 +123,24 @@ def tess_base_args(langs, engine_mode):
     return args
 
 
-def get_orientation(input_file, language: list, engine_mode, timeout: float,
-                    log):
+def get_orientation(input_file, engine_mode, timeout: float, log):
     args_tesseract = tess_base_args(['osd'], engine_mode) + [
-        psm(), '0',
-        input_file,
-        'stdout'
+        '--psm',
+        '0',
+        fspath(input_file),
+        'stdout',
     ]
 
     try:
-        stdout = check_output(
-            args_tesseract, stderr=STDOUT, timeout=timeout)
+        stdout = check_output(args_tesseract, stderr=STDOUT, timeout=timeout)
     except TimeoutExpired:
         return OrientationConfidence(angle=0, confidence=0.0)
     except CalledProcessError as e:
         tesseract_log_output(log, e.output, input_file)
-        if (b'Too few characters. Skipping this page' in e.output or
-                b'Image too large' in e.output):
+        if (
+            b'Too few characters. Skipping this page' in e.output
+            or b'Image too large' in e.output
+        ):
             return OrientationConfidence(0, 0)
         raise e from e
     else:
@@ -153,32 +152,24 @@ def get_orientation(input_file, language: list, engine_mode, timeout: float,
                 osd[parts[0].strip()] = parts[1].strip()
 
         angle = int(osd.get('Orientation in degrees', 0))
-        if 'Orientation' in osd:
-            # Tesseract < 3.04.01
-            # reports "Orientation in degrees" as a counterclockwise angle
-            # We keep it clockwise
-            assert 'Rotate' not in osd
-            angle = -angle % 360
-        else:
-            # Tesseract >= 3.04.01
-            # reports "Orientation in degrees" as a clockwise angle
-            assert 'Rotate' in osd
-
         oc = OrientationConfidence(
-            angle=angle,
-            confidence=float(osd.get('Orientation confidence', 0)))
+            angle=angle, confidence=float(osd.get('Orientation confidence', 0))
+        )
         return oc
 
 
 def tesseract_log_output(log, stdout, input_file):
-    prefix = "{0:4d}: [tesseract] ".format(page_number(input_file))
+    prefix = f"{(page_number(input_file)):4d}: [tesseract] "
 
     try:
         text = stdout.decode()
     except UnicodeDecodeError:
-        log.error(prefix + "command line output was not utf-8. " +
-            "This usually means Tesseract's language packs do not match "
-            "the installed version of Tesseract.")
+        log.error(
+            prefix
+            + "command line output was not utf-8. "
+            + "This usually means Tesseract's language packs do not match "
+            "the installed version of Tesseract."
+        )
         text = stdout.decode('utf-8', 'backslashreplace')
 
     lines = text.splitlines()
@@ -191,6 +182,14 @@ def tesseract_log_output(log, stdout, input_file):
             log.warning(prefix + "lots of diacritics - possibly poor OCR")
         elif line.startswith('OSD: Weak margin'):
             log.warning(prefix + "unsure about page orientation")
+        elif 'Error in pixScanForForeground' in line:
+            pass  # Appears to be spurious/problem with nonwhite borders
+        elif 'Error in boxClipToRectangle' in line:
+            pass  # Always appears with pixScanForForeground message
+        elif 'parameter not found: ' in line.lower():
+            log.error(prefix + line.strip())
+            problem = line.split('found: ')[1]
+            raise TesseractConfigError(problem)
         elif 'error' in line.lower() or 'exception' in line.lower():
             log.error(prefix + line.strip())
         elif 'warning' in line.lower():
@@ -202,7 +201,7 @@ def tesseract_log_output(log, stdout, input_file):
 
 
 def page_timedout(log, input_file):
-    prefix = "{0:4d}: [tesseract] ".format(page_number(input_file))
+    prefix = f"{(page_number(input_file)):4d}: [tesseract] "
     log.warning(prefix + " took too long to OCR - skipping")
 
 
@@ -220,10 +219,18 @@ def _generate_null_hocr(output_hocr, output_sidecar, image):
         f.write('[skipped page]')
 
 
-def generate_hocr(input_file, output_files, language: list, engine_mode,
-                  tessconfig: list,
-                  timeout: float, pagesegmode: int, user_words, user_patterns,
-                  log):
+def generate_hocr(
+    input_file,
+    output_files,
+    language: list,
+    engine_mode,
+    tessconfig: list,
+    timeout: float,
+    pagesegmode: int,
+    user_words,
+    user_patterns,
+    log,
+):
 
     output_hocr = next(o for o in output_files if o.endswith('.hocr'))
     output_sidecar = next(o for o in output_files if o.endswith('.txt'))
@@ -232,7 +239,7 @@ def generate_hocr(input_file, output_files, language: list, engine_mode,
     args_tesseract = tess_base_args(language, engine_mode)
 
     if pagesegmode is not None:
-        args_tesseract.extend([psm(), str(pagesegmode)])
+        args_tesseract.extend(['--psm', str(pagesegmode)])
 
     if user_words:
         args_tesseract.extend(['--user-words', user_words])
@@ -242,20 +249,10 @@ def generate_hocr(input_file, output_files, language: list, engine_mode,
 
     # Reminder: test suite tesseract spoofers will break after any changes
     # to the number of order parameters here
-    # Tesseract 3.04 requires the order here to be "hocr txt" and will fail
-    # on "txt hocr"
-
-    args_tesseract.extend([
-        input_file,
-        prefix,
-        'hocr',
-        'txt'
-    ] + tessconfig)
+    args_tesseract.extend([input_file, prefix, 'hocr', 'txt'] + tessconfig)
     try:
         log.debug(args_tesseract)
-        stdout = check_output(
-            args_tesseract, stderr=STDOUT,
-            timeout=timeout)
+        stdout = check_output(args_tesseract, stderr=STDOUT, timeout=timeout)
     except TimeoutExpired:
         # Generate a HOCR file with no recognized text if tesseract times out
         # Temporary workaround to hocrTransform not being able to function if
@@ -264,8 +261,6 @@ def generate_hocr(input_file, output_files, language: list, engine_mode,
         _generate_null_hocr(output_hocr, output_sidecar, input_file)
     except CalledProcessError as e:
         tesseract_log_output(log, e.output, input_file)
-        if b'read_params_file: parameter not found' in e.output:
-            raise TesseractConfigError() from e
         if b'Image too large' in e.output:
             _generate_null_hocr(output_hocr, output_sidecar, input_file)
             return
@@ -283,33 +278,34 @@ def use_skip_page(text_only, skip_pdf, output_pdf, output_text):
     with open(output_text, 'w') as f:
         f.write('[skipped page]')
 
-    if not text_only:
+    if skip_pdf and not text_only:
+        # Substitute a "skipped page"
         with suppress(FileNotFoundError):
             os.remove(output_pdf)  # In case it was partially created
         os.symlink(skip_pdf, output_pdf)
         return
 
-    # For text only we must create a blank page with dimensions identical
-    # to the skip page because this is equivalent to a page with no text
-
-    pdf_in = pypdf.PdfFileReader(skip_pdf)
-    page0 = pdf_in.pages[0]
-
+    # Or normally, just write a 0 byte file to the output to indicate a skip
     with open(output_pdf, 'wb') as out:
-        pdf_out = pypdf.PdfFileWriter()
-        w, h = page0.mediaBox.getWidth(), page0.mediaBox.getHeight()
-        # If skip page has a /Rotate key, replicate the rotation
-        rotation = int(page0.get('/Rotate', 0))
-        if rotation % 180 == 90:
-            w, h = h, w
-        pdf_out.addBlankPage(w, h)
-        pdf_out.write(out)
+        out.write(b'')
 
 
-def generate_pdf(*, input_image, skip_pdf, output_pdf, output_text,
-                 language: list, engine_mode, text_only: bool,
-                 tessconfig: list, timeout: float, pagesegmode: int,
-                 user_words, user_patterns, log):
+def generate_pdf(
+    *,
+    input_image,
+    skip_pdf=None,
+    output_pdf,
+    output_text,
+    language: list,
+    engine_mode,
+    text_only: bool,
+    tessconfig: list,
+    timeout: float,
+    pagesegmode: int,
+    user_words,
+    user_patterns,
+    log,
+):
     '''Use Tesseract to render a PDF.
 
     input_image -- image to analyze
@@ -327,9 +323,9 @@ def generate_pdf(*, input_image, skip_pdf, output_pdf, output_text,
     args_tesseract = tess_base_args(language, engine_mode)
 
     if pagesegmode is not None:
-        args_tesseract.extend([psm(), str(pagesegmode)])
+        args_tesseract.extend(['--psm', str(pagesegmode)])
 
-    if text_only:
+    if text_only and has_textonly_pdf():
         args_tesseract.extend(['-c', 'textonly_pdf=1'])
 
     if user_words:
@@ -343,18 +339,11 @@ def generate_pdf(*, input_image, skip_pdf, output_pdf, output_text,
     # Reminder: test suite tesseract spoofers might break after any changes
     # to the number of order parameters here
 
-    args_tesseract.extend([
-        input_image,
-        prefix,
-        'pdf',
-        'txt'
-    ] + tessconfig)
+    args_tesseract.extend([input_image, prefix, 'pdf', 'txt'] + tessconfig)
 
     try:
         log.debug(args_tesseract)
-        stdout = check_output(
-            args_tesseract, stderr=STDOUT,
-            timeout=timeout)
+        stdout = check_output(args_tesseract, stderr=STDOUT, timeout=timeout)
         if os.path.exists(prefix + '.txt'):
             shutil.move(prefix + '.txt', output_text)
     except TimeoutExpired:
@@ -362,9 +351,6 @@ def generate_pdf(*, input_image, skip_pdf, output_pdf, output_text,
         use_skip_page(text_only, skip_pdf, output_pdf, output_text)
     except CalledProcessError as e:
         tesseract_log_output(log, e.output, input_image)
-        if b'read_params_file: parameter not found' in e.output:
-            raise TesseractConfigError() from e
-
         if b'Image too large' in e.output:
             use_skip_page(text_only, skip_pdf, output_pdf, output_text)
             return
