@@ -20,18 +20,6 @@
 # TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-
-from pathlib import Path
-import sys
-import os
-import shutil
-import subprocess
-import argparse
-import json
-import platform
-import re
-
-
 """Cache output of tesseract to speed up test suite
 
 The cache is keyed by an environment variable that slips the input test file
@@ -57,25 +45,31 @@ machines with AVX2, the cache is now bundled.
 
 Certain operations are not cached and routed to tesseract directly.
 
-Assumes Tesseract 3.04 or higher.
-
-Will fail on Tesseract 3.02.02 in "hocr" mode because it doesn't produce
-the incorrect file extension. Will fail on 3.03 because that has no sidecar
-text support. Will fail to replicate a 3.04 bug if wrong parameter order is
-given.
+Assumes Tesseract 4.0.0-alpha or higher.
 
 """
 
+import argparse
+import json
+import os
+import platform
+import re
+import shutil
+import subprocess
+import sys
+from pathlib import Path
+
 if '_OCRMYPDF_SAVE_PATH' in os.environ:
     os.environ['PATH'] = os.environ['_OCRMYPDF_SAVE_PATH']
 
 __version__ = subprocess.check_output(
-        ['tesseract', '--version'],
-        stderr=subprocess.STDOUT).decode()
+    ['tesseract', '--version'], stderr=subprocess.STDOUT
+).decode()
 
 
 parser = argparse.ArgumentParser(
-    prog='tesseract-cache', description='cache output of tesseract')
+    prog='tesseract-cache', description='cache output of tesseract'
+)
 parser.add_argument('-l', '--language', action='append')
 parser.add_argument('imagename')
 parser.add_argument('outputbase')
@@ -89,6 +83,7 @@ parser.add_argument('--oem', type=int)
 TESTS_ROOT = Path(__file__).resolve().parent.parent
 CACHE_ROOT = TESTS_ROOT / 'cache'
 
+
 def real_tesseract():
     tess_args = ['tesseract'] + sys.argv[1:]
     os.execvp("tesseract", tess_args)
@@ -96,8 +91,10 @@ def real_tesseract():
 
 
 def main():
-    if any(opt in sys.argv[1:] for opt in (
-            '--print-parameters', '--list-langs', '--version')):
+    if any(
+        opt in sys.argv[1:]
+        for opt in ('--print-parameters', '--list-langs', '--version')
+    ):
         real_tesseract()  # jump into real tesseract, replacing this process
 
     # Convert non-standard but supported -psm to --psm
@@ -118,17 +115,18 @@ def main():
                 yield Path(args.imagename).name
             elif arg == args.outputbase:
                 yield Path(args.outputbase).name
+            elif arg == '-c' or arg.startswith('textonly'):
+                pass
             else:
                 yield arg
 
     argv_slug = '__'.join(slugs())
     argv_slug = argv_slug.replace('/', '___')
-    
-    cache_folder = Path(CACHE_ROOT) / Path(source).stem / argv_slug
-    cache_folder.mkdir(parents=True, exist_ok=True)        
 
-    print("Tesseract cache folder {} - ".format(cache_folder), end='', 
-          file=sys.stderr)
+    cache_folder = Path(CACHE_ROOT) / Path(source).stem / argv_slug
+    cache_folder.mkdir(parents=True, exist_ok=True)
+
+    print(f"Tesseract cache folder {cache_folder} - ", end='', file=sys.stderr)
 
     if (cache_folder / 'stderr.bin').exists() and not cache_disabled:
         # Cache hit
@@ -143,8 +141,7 @@ def main():
             for configfile in args.configfiles:
                 # cp cache -> output
                 tessfile = args.outputbase + '.' + configfile
-                shutil.copy(str(cache_folder / configfile) + '.bin', 
-                            tessfile)
+                shutil.copy(str(cache_folder / configfile) + '.bin', tessfile)
         sys.exit(0)
 
     # Cache miss
@@ -153,8 +150,8 @@ def main():
     # Call tesseract
     print(sys.argv[1:])
     p = subprocess.run(
-            ['tesseract'] + sys.argv[1:],
-            stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        ['tesseract'] + sys.argv[1:], stdout=subprocess.PIPE, stderr=subprocess.PIPE
+    )
     sys.stdout.buffer.write(p.stdout)
     sys.stderr.buffer.write(p.stderr)
 
@@ -184,11 +181,14 @@ def main():
     manifest['python'] = platform.python_version()
     manifest['argv_slug'] = argv_slug
     manifest['sourcefile'] = str(Path(source).relative_to(TESTS_ROOT))
+
     def clean_sys_argv():
         for arg in sys.argv[1:]:
-            yield re.sub(r'.*/com.github.ocrmypdf[^/]+[/](.*)', 
-                         r'$TMPDIR/\1', arg)
+            yield re.sub(r'.*/com.github.ocrmypdf[^/]+[/](.*)', r'$TMPDIR/\1', arg)
+
     manifest['args'] = list(clean_sys_argv())
+
+    # pylint: disable=E1101
     with (Path(CACHE_ROOT) / 'manifest.jsonl').open('a') as f:
         json.dump(manifest, f)
         f.write('\n')
