@@ -20,15 +20,16 @@
 # TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-import sys
-import os
 import signal
+import sys
 
-
-VERSION_STRING = '''tesseract 3.05.01
- leptonica-1.74.4
-  libjpeg 9b : libpng 1.6.32 : libtiff 4.0.8 : zlib 1.2.8
-SPOOFED: CRASH ON OCR or -psm 0
+VERSION_STRING = '''tesseract 4.0.0
+ leptonica-1.77.0
+  libjpeg 9c : libpng 1.6.35 : libtiff 4.0.10 : zlib 1.2.11 : libopenjp2 2.3.0
+ Found AVX2
+ Found AVX
+ Found SSE
+SPOOFED: CRASH ON OCR or --psm 0
 '''
 
 """Simulates a Tesseract crash when asked to run OCR
@@ -50,8 +51,7 @@ def main():
         print('List of available languages (1):\neng', file=sys.stderr)
         sys.exit(0)
     elif sys.argv[1] == '--print-parameters':
-        print('A parameter list would go here\ntextonly_pdf 0\n',
-              file=sys.stderr)
+        print('A parameter list would go here\ntextonly_pdf 0\n', file=sys.stderr)
         sys.exit(0)
     elif sys.argv[-2] == 'hocr':
         print("KABOOM! Tesseract failed for some reason", file=sys.stderr)
@@ -60,8 +60,11 @@ def main():
         print("KABOOM! Tesseract failed for some reason", file=sys.stderr)
         sys.exit(128 + signal.SIGSEGV)
     elif sys.argv[-1] == 'stdout':
-        print("libc++abi.dylib: terminating with uncaught exception of type "
-              "std::bad_alloc: std::bad_alloc", file=sys.stderr)
+        print(
+            "libc++abi.dylib: terminating with uncaught exception of type "
+            "std::bad_alloc: std::bad_alloc",
+            file=sys.stderr,
+        )
         sys.exit(128 + signal.SIGABRT)
     else:
         print("Spoof doesn't understand arguments", file=sys.stderr)
