@@ -15,27 +15,22 @@
 # You should have received a copy of the GNU General Public License
 # along with OCRmyPDF.  If not, see <http://www.gnu.org/licenses/>.
 
-from ocrmypdf import hocrtransform
-from ocrmypdf.exec.tesseract import HOCR_TEMPLATE
-from ocrmypdf.exec import qpdf
-from reportlab.pdfgen.canvas import Canvas
-from PIL import Image
-from tempfile import NamedTemporaryFile
-from contextlib import suppress
 from pathlib import Path
-import os
-import shutil
+
 import pytest
-import img2pdf
-import pytest
-import sys
+from PIL import Image
+
+from ocrmypdf import hocrtransform
+from ocrmypdf.exec import qpdf
+from ocrmypdf.exec.tesseract import HOCR_TEMPLATE
+
+# pylint: disable=redefined-outer-name
 
 
 @pytest.fixture
 def blank_hocr(tmpdir):
     filename = Path(str(tmpdir)) / "blank.hocr"
-    with open(str(filename), 'w') as f:
-        f.write(HOCR_TEMPLATE)
+    filename.write_text(HOCR_TEMPLATE)  # pylint: disable=E1101
     return filename
 
 
@@ -46,10 +41,6 @@ def test_mono_image(blank_hocr, outdir):
     im.save(outdir / 'mono.tif', format='TIFF')
 
     hocr = hocrtransform.HocrTransform(str(blank_hocr), 300)
-    hocr.to_pdf(
-        str(outdir / 'mono.pdf'), imageFileName=str(outdir / 'mono.tif'))
+    hocr.to_pdf(str(outdir / 'mono.pdf'), imageFileName=str(outdir / 'mono.tif'))
 
     qpdf.check(str(outdir / 'mono.pdf'))
-
-
-
