@@ -16,7 +16,9 @@
 # along with OCRmyPDF.  If not, see <http://www.gnu.org/licenses/>.
 
 from pathlib import Path
+
 import pytest
+
 from ocrmypdf.exceptions import ExitCode
 
 # pytest.helpers is dynamic
@@ -27,27 +29,27 @@ check_ocrmypdf = pytest.helpers.check_ocrmypdf
 run_ocrmypdf = pytest.helpers.run_ocrmypdf
 spoof = pytest.helpers.spoof
 
+
 @pytest.fixture(scope='session')
 def spoof_unpaper_oldversion(tmpdir_factory):
     return spoof(tmpdir_factory, unpaper='unpaper_oldversion.py')
 
 
-@pytest.mark.skipif(True, 
-                    reason="needs new fixture implementation")
+@pytest.mark.skipif(True, reason="needs new fixture implementation")
 def test_no_unpaper(resources, no_outpdf):
     # <disable unpaper here>
     p, out, err = run_ocrmypdf(
-        resources / 'c02-22.pdf', no_outpdf, '--clean', env=os.environ)
+        resources / 'c02-22.pdf', no_outpdf, '--clean', env=os.environ
+    )
     assert p.returncode == ExitCode.missing_dependency
 
 
 def test_old_unpaper(spoof_unpaper_oldversion, resources, no_outpdf):
     p, out, err = run_ocrmypdf(
-        resources / 'c02-22.pdf', no_outpdf, '--clean', 
-        env=spoof_unpaper_oldversion)
+        resources / 'c02-22.pdf', no_outpdf, '--clean', env=spoof_unpaper_oldversion
+    )
     assert p.returncode == ExitCode.missing_dependency
 
 
 def test_clean(spoof_tesseract_noop, resources, outpdf):
-    check_ocrmypdf(resources / 'skew.pdf', outpdf, '-c',
-                   env=spoof_tesseract_noop)
\ No newline at end of file
+    check_ocrmypdf(resources / 'skew.pdf', outpdf, '-c', env=spoof_tesseract_noop)
